@@ -31,7 +31,7 @@ def create_pipeline():
 
     # Set up the img2img pipeline from pretrained Stable Diffusion model
     device = 'cuda' if torch.cuda.is_available() else 'cpu'
-    print(f'using {device =}')
+
     #device = "cuda"
     model_id_or_path = "CompVis/stable-diffusion-v1-4"
     pipe = StableDiffusionImg2ImgPipeline.from_pretrained(
@@ -41,6 +41,7 @@ def create_pipeline():
         use_auth_token=access_token
     )
     pipe = pipe.to(device)
+    print(f'Created Img2Img Pipeline using: {device}')
     return pipe
 
 def run_pipeline(pipe,
